Changelog
---------
0.5.1 (2018-12-09)
~~~~~~~~~~~~~~~~~~~~~

- Updates requirements.
  [msom]

0.5.0 (2018-11-28)
~~~~~~~~~~~~~~~~~~~~~

- Allows to add SVG header logos.
  [msom]

0.4.0 (2018-10-30)
~~~~~~~~~~~~~~~~~~~~~

- Allows to add table of contents to PDFs.
  [msom]

- Allows to add h5 and h6 headings to PDFs.
  [msom]

- Allows to add a header by level.
  [msom]

- Allows to add images to PDFs.
  [msom]

- Allows to add a creation date to the header.
  [msom]

- Adds an option to linkify the html when adding to PDFs.
  [msom]

0.3.5 (2018-10-04)
~~~~~~~~~~~~~~~~~~~~~

- Adds missing html5lib dependency.
  [href]

0.3.4 (2018-05-21)
~~~~~~~~~~~~~~~~~~~~~

- Fixes adding mini html for an empty string throwing an error.
  [msom]

0.3.3 (2018-01-18)
~~~~~~~~~~~~~~~~~~~~~

- Fixes handling of whitespace in mini html.
  [msom]

0.3.2 (2018-01-11)
~~~~~~~~~~~~~~~~~~~~~

- Adds support for indentation of lists.
  [msom]

- Fixes handling of whitespace in mini html.
  [msom]

0.3.1 (2018-01-10)
~~~~~~~~~~~~~~~~~~~~~

- Requires Python 3.6.
  [href]

- Adds compatibility with onegov.file.
  [msom]

0.3.0 (2017-11-17)
~~~~~~~~~~~~~~~~~~~~~

- Rewrites the mini_html function to use list flowables and a HTML sanitizer/
  cleaner.
  [msom]

- Adds h4.
  [msom]

0.2.0 (2017-11-14)
~~~~~~~~~~~~~~~~~~~~~

- Adds a generic header and footer.
  [msom]

0.1.1 (2017-11-13)
~~~~~~~~~~~~~~~~~~~~~

- Adds lexwork PDF signer.
  [msom]

0.1.0 (2017-11-13)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release
